@@ -3,7 +3,7 @@
 # Business::Bitcoin::Request - Bitcoin payment request
 # Copyright (c) 2016 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin/Request.pm v1.021 Thu Jan 19 12:17:31 PST 2017 $
+# $Id: lib/Business/Bitcoin/Request.pm v1.023 Thu Jan 19 13:29:51 PST 2017 $
 
 use strict;
 
@@ -20,7 +20,7 @@ use Crypt::RIPEMD160;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.021 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.023 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %args) = @_;
@@ -84,25 +84,20 @@ sub _getaddress {
 sub _CKDpub {
   my ($K, $c, $i) = @_;
   my $curve = Math::EllipticCurve::Prime->from_name('secp256k1');
-  my $Kc = _compress($K);
-  $Kc =~ s/(([0-9a-f][0-9a-f])+)/pack("H*", $1)/ie;
-  $c =~ s/(([0-9a-f][0-9a-f])+)/pack("H*", $1)/ie;
+  my $Kc = pack('H*', _compress($K));
   my $data = $Kc . pack ('L>', $i);
-  my $hmac = hmac_sha512_hex($data, $c); $hmac =~ /(.{64})(.{64})/;
+  my $hmac = hmac_sha512_hex($data, pack('H*', $c)); $hmac =~ /(.{64})(.{64})/;
   my ($Il, $ci) = ($1, $2);
   my $Ki = $curve->g->multiply(Math::BigInt->from_hex($Il))->add($K);
   return ($Ki, $ci);
 }
 
 sub _address {
-  my $Kc = shift;
-  $Kc =~ s/(([0-9a-f][0-9a-f])+)/pack("H*", $1)/ie;
+  my $Kc = pack('H*', shift);
   my $sha256 = sha256($Kc);
   my $id = '00' . Crypt::RIPEMD160->hexhash($sha256); $id =~ s/\s//g;
-  my $idhex = $id;
-  $id =~ s/(([0-9a-f][0-9a-f])+)/pack("H*", $1)/ie;
-  my $checksum = substr(sha256_hex(sha256($id)), 0, 8);
-  my $addrstr = $idhex . $checksum;
+  my $checksum = substr(sha256_hex(sha256(pack('H*', $id))), 0, 8);
+  my $addrstr = $id . $checksum;
   return '1' . _encode58(Math::BigInt->from_hex($addrstr));
 }
 
@@ -161,8 +156,8 @@ Business::Bitcoin::Request - Bitcoin payment request
 
 =head1 VERSION
 
- $Revision: 1.021 $
- $Date: Thu Jan 19 12:17:31 PST 2017 $
+ $Revision: 1.023 $
+ $Date: Thu Jan 19 13:29:51 PST 2017 $
 
 =head1 SYNOPSIS
 
